Shared slot hash cache accessible from both server and interpreter
This module provides a global cache for slot hashes that is populated by the gRPC stream and accessed by computed field resolvers.
Functions
- get_
slot_ hash - Get a slot hash from the global cache
- has_
slot_ hash - Check if a slot hash is in the cache
- record_
slot_ hash - Record a slot hash in the global cache