pub struct ErasedStreamSpec {
pub spec_name: String,
pub entity_name: String,
pub description: Option<String>,
/* private fields */
}Expand description
Type-erased stream spec that can be used across crate boundaries
This allows the CLI to work with specs without knowing the concrete state type
Fields
spec_name: Stringentity_name: Stringdescription: Option<String>Implementations