Module slot_hash_cache

Module slot_hash_cache 

Shared slot hash cache accessible from both server and interpreter

This module provides a global cache for slot hashes that is populated by the gRPC stream and accessed by computed field resolvers.

Functions

get_slot_hash
Get a slot hash from the global cache
has_slot_hash
Check if a slot hash is in the cache
record_slot_hash
Record a slot hash in the global cache